## Not run:
# # Load the LR transcriptomic dataset
# data(LR_dataset)
#
# # Load the vectors of genes codes, gene names and prior
# data(l_genes)
# data(l_names)
# data(l_prior)
#
# # Load the vector of time points for the LR_dataset
# data(times)
#
# # Generate the TPI database (this may take several hours)
#
# TPI10=CalculateTPI(dataset=LR_dataset,l_genes=l_genes,l_prior=l_prior,
# times=times,time_step=1,N=10000,ks_int=c(0.5,3),kd_int=c(0.5,3),
# delta_int=c(0.5,3),noise=0.1,delay=3)
#
# # Generate the DPI database (this may take several hours)
#
# DPI15=CalculateDPI(dataset=LR_dataset,l_genes=l_genes,l_prior=l_prior,
# times=times,time_step=1,N=10000,ks_int=c(0.5,3),kd_int=c(0.5,3),
# delta_int=c(0.5,3), noise=0.15, delay=3)
#
# # Check/update if necessary the databases
#
# TPI10=UpdateTPI(TPI10,LR_dataset,l_genes,l_prior)
# DPI15=UpdateDPI(DPI15,LR_dataset,l_genes,l_prior)
#
# # Choose your parameters
#
# ptime_step=1
# ptol=0.13
# pdelayspan=12
# pthr_cor=c(0.65,0.8)
# pdelaymax=c(2.5,3.5)
# pdelaymin=0
# pdelay=3
# pthrpTPI=c(0.55,0.8)
# pthrpDPI=c(0.65,0.8)
# pthr_overlap=c(0.4,0.6)
# pthr_ind1=0.65
# pthr_ind2=3.5
# pn0=1000
# pn1=10
# pregmax=5
# pthr_isr=c(4,6)
# pTPI=TPI10
# pDPI=DPI15
# pMinTarNumber=5
# pMinProp=0.6
# poutfile_name="TDCor_output.txt"
#
#
# # Reconstruct the network
#
# tdcor_out= TDCOR(dataset=LR_dataset, l_genes=l_genes,l_names=l_names,n0=pn0,n1=pn1,
# l_prior=l_prior, thr_ind1=pthr_ind1,thr_ind2=pthr_ind2,regmax=pregmax,thr_cor=pthr_cor,
# delayspan=pdelayspan,delaymax=pdelaymax,delaymin=pdelaymin,delay=pdelay,thrpTPI=pthrpTPI,
# thrpDPI=pthrpDPI,TPI=pTPI,DPI=pDPI,thr_isr=pthr_isr,time_step=ptime_step,thr_overlap=pthr_overlap,
# tol=ptol,MinProp=pMinProp,MinTarNumber=pMinTarNumber,outfile_name=poutfile_name)
#
# ## End(Not run)
Run the code above in your browser using DataLab