Learn R Programming

TDCor (version 0.1-2)

clean.at: Elimininate from a vector of gene codes the genes for which no data is available.

Description

clean.at removes from a vector of gene codes l_genes all the elements for which no data is present in the matrix dataset.

Usage

clean.at(dataset,l_genes)

Arguments

dataset
A matrix containing the time-series transcriptomic data whose rows must be named by gene codes (like AGI gene codes).
l_genes
A character vector which contains gene codes (AGI gene codes in the case of the lateral root dataset).

Examples

Run this code
## Load lateral root transcriptomic dataset and the l_genes vector
data(LR_dataset)
data(l_genes)

# Clean the l_gene vector 
clean.at(LR_dataset,l_genes)

Run the code above in your browser using DataLab