Learn R Programming

TDCor (version 0.1-2)

draw.profile: Plot the expression profile of a gene in dataset

Description

draw.profile plots the expression profile of gene in dataset with respect to times.

Usage

draw.profile(dataset, gene, ...)

Arguments

dataset
The matrix storing the time-serie transcriptomic data.
gene
The AGI code of the gene of interest.
...
Additional arguments to be passed to the function:
  • col: String. Color of the curve.
  • type: String. Type of curve. "l", lines; "p", points; "b", both etc... For more information see the help file of the plot R function.
  • main: String. Title of the graph.

Examples

Run this code
# draw the profile of GATA23 in the LR dataset

data(LR_dataset)
data(times)
draw.profile(LR_dataset,"AT5G26930",col="blue",main="GATA23")

Run the code above in your browser using DataLab