Learn R Programming

TDCor (version 0.1-2)

times: The times vector to use with the lateral root dataset

Description

Contains the times (in hours) at which the samples were collected to generate the Lateral Root transcriptomic dataset (data(LR_dataset))

Usage

data("times")

Arguments

Examples

Run this code
# Load the vector associated with the LR dataset
data(times)

# Have a look at it
times

Run the code above in your browser using DataLab